- Crée une application Django avec :
  - un fichier `urls.py` directement généré,
  - un dossier `views/` au lieu d'un simple `views.py`,
  - un dossier `models/` au lieu d'un seul `models.py`,
  - une structure claire prête pour des projets plus complexes.

